@@ -1,7 +1,7 @@
 package Perinci::Result::Format;
 
-our $DATE = '2015-02-24'; # DATE
-our $VERSION = '0.39'; # VERSION
+our $DATE = '2015-03-10'; # DATE
+our $VERSION = '0.40'; # VERSION
 
 use 5.010001;
 use strict;
@@ -107,7 +107,7 @@ my $format_text = sub {
     my ($r, $opts);
     if ($res->[0] =~ /\A2../) {
         $r = $res->[2];
-        my $rfo = $res->[3]{result_format_options} // {};
+        my $rfo = $res->[3]{format_options} // {};
         if ($rfo->{$format}) {
             $opts = $rfo->{$format};
         } elsif ($rfo->{any}) {
@@ -190,7 +190,7 @@ Perinci::Result::Format - Format envelope result
 
 =head1 VERSION
 
-This document describes version 0.39 of Perinci::Result::Format (from Perl distribution Perinci-Result-Format), released on 2015-02-24.
+This document describes version 0.40 of Perinci::Result::Format (from Perl distribution Perinci-Result-Format), released on 2015-03-10.
 
 =head1 SYNOPSIS
 
@@ -272,12 +272,12 @@ None is currently exported/exportable.
 Format enveloped result C<$res> with format named C<$format>.
 
 Result metadata (C<< $res->[3] >>) is also checked for key named
-C<result_format_options>. The value should be a hash like this C<< { FORMAT_NAME
-=> OPTS, ... } >>. This way, function results can specify the details of
-formatting. An example enveloped result:
+C<format_options>. The value should be a hash like this C<< { FORMAT_NAME =>
+OPTS, ... } >>. FORMAT_NAME can be C<any> to mean any format. This way, function
+results can specify the details of formatting. An example enveloped result:
 
  [200, "OK", ["foo", "bar", "baz"], {
-     result_format_options => {
+     format_options => {
          "text"        => {list_max_columns=>1},
          "text-pretty" => {list_max_columns=>1},
      }
@@ -291,7 +291,7 @@ multicolumns.
 
 =over
 
-=item * property: result_format_options => HASH
+=item * property: format_options => HASH
 
 =back
 
